@@ -61,7 +61,7 @@ def configure_cli():
     controller_username = None
     controller_password = None
 
-    config_path = os.path.join(os.path.expanduser("~"), ".hpecp.conf",)
+    config_path = os.path.join(os.path.expanduser("~"), ".hpecp.conf")
 
     if os.path.exists(config_path):
         config_reader = ContainerPlatformClient.create_from_config_file()
@@ -204,7 +204,7 @@ class AutoComplete:
 
         return (modules, columns)
 
-    def bash(self,):
+    def bash(self):
         """Create autocompletion script for bash."""
         __bash_template = dedent(
             """\
@@ -386,12 +386,19 @@ class AutoComplete:
         )
 
 
-def version():
+def version(debug=False):
     """Display version information."""
-    print("HPECP Version:  " + ContainerPlatformClient.version())
-    print("HPECP Path:     " + hpecp.__file__)
-    print("Python Version: " + sys.version.replace("\n", ""))
-    print("Python Path:    " + sys.executable)
+    print("HPECP Version:   " + ContainerPlatformClient.version())
+
+    if debug:
+        print("HPECP Bin Path:  " + os.path.dirname(os.path.abspath(__file__)))
+        print(
+            "HPECP Lib Path:  " + os.path.dirname(os.path.abspath(hpecp.__file__))
+        )
+        print("Python Version:  " + sys.version.replace("\n", ""))
+        print("Python Exe Path: " + sys.executable)
+        print("Python Path:     " + os.pathsep.join(sys.path))
+        print("System Path:     " + os.environ.get("PATH", ""))
 
 
 class CLI(object):
@@ -401,7 +408,7 @@ class CLI(object):
         """Return modules names."""
         return list(vars(self))
 
-    def __init__(self,):
+    def __init__(self):
         """Create a CLI instance."""
         self.autocomplete = AutoComplete(self)
         self.configure_cli = configure_cli
